package
Version:
v0.0.0-...-18df7f0
Opens a new window with list of versions in this module.
Published: Jul 25, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Todo struct {
ID string `json:"id"`
Title string `json:"title"`
Description string `json:"description"`
CreateAt int64 `json:"created_at"`
}
type User struct {
ID string `json:"id"`
FirstName string `json:"firstname"`
LastName string `json:"lastname"`
Email string `json:"email"`
Password string `json:"password"`
Avater string `json:"avater"`
Todo []Todo
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.